@@ -14,6 +14,6 @@ $SUDO bash -c 'echo "SUBSYSTEMS==\"usb\", ATTRS{product}==\"CP2102 USB to UART B
 cd `dirname $0`
 ARCH=`uname -m`
 
-exec ./settings-$ARCH "$@"
+LD_LIBRARY_PATH=lib exec ./settings-$ARCH "$@"
 
 rm -f /tmp/.spirit-settings
